@@ -13,8 +13,7 @@
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,7 +27,6 @@
 #include <cstdlib>
 #include <cstdio>
 #include <cassert>
-#include <string>
 #include <cmath>
 #include <iostream>
 #include <iomanip>
@@ -102,7 +100,11 @@ QString KExiv2::Exiv2Version()
                               .arg(EXIV2_PATCH_VERSION);
 }
 
-// -- Protected Methods -------------------------------------
+void KExiv2::printExiv2ExceptionError(const QString& msg, Exiv2::Error& e)
+{
+    std::string s(e.what());
+    qDebug("%s (%s)", msg.ascii(), s.c_str());
+}
 
 std::string& KExiv2::commentsMetaData()
 {
@@ -119,8 +121,6 @@ Exiv2::IptcData& KExiv2::iptcMetaData()
     return d->iptcMetadata;
 }
 
-// -- Public Methods --------------------------------
-
 bool KExiv2::clearComments()
 {
     return setComments(QByteArray());
@@ -135,7 +135,7 @@ bool KExiv2::clearExif()
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot clear Exif data using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot clear Exif data using Exiv2 ", e);
     }    
 
     return false;       
@@ -150,7 +150,7 @@ bool KExiv2::clearIptc()
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot clear Iptc data using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot clear Iptc data using Exiv2 ", e);
     }    
 
     return false;       
@@ -196,7 +196,7 @@ QByteArray KExiv2::getExif() const
         if (!d->filePath.isEmpty())
             qDebug ("From file %s", d->filePath.ascii());
 
-        qDebug("Cannot get Exif data using Exiv2 (%s", e.what().c_str());
+        printExiv2ExceptionError("Cannot get Exif data using Exiv2 ", e);
     }       
     
     return QByteArray();
@@ -237,7 +237,7 @@ QByteArray KExiv2::getIptc(bool addIrbHeader) const
         if (!d->filePath.isEmpty())
             qDebug ("From file %s", d->filePath.ascii());
 
-        qDebug("Cannot get Iptc data using Exiv2 (%s)",e.what().c_str());
+        printExiv2ExceptionError("Cannot get Iptc data using Exiv2 ",e);
     }       
     
     return QByteArray();
@@ -266,7 +266,7 @@ bool KExiv2::setExif(const QByteArray& data)
         if (!d->filePath.isEmpty())
             qDebug ("From file %s", d->filePath.ascii());
 
-        qDebug("Cannot set Exif data using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif data using Exiv2 ", e);
     }        
 
     return false;
@@ -289,7 +289,7 @@ bool KExiv2::setIptc(const QByteArray& data)
         if (!d->filePath.isEmpty())
             qDebug ("From file %s", d->filePath.ascii());
 
-        qDebug("Cannot set Iptc data using Exiv2 (%s)",e.what().c_str());
+        printExiv2ExceptionError("Cannot set Iptc data using Exiv2 ", e);
     }    
 
     return false;    
@@ -312,7 +312,7 @@ bool KExiv2::setExif(Exiv2::DataBuf const data)
         if (!d->filePath.isEmpty())
             qDebug ("From file %s", d->filePath.ascii());
 
-        qDebug("Cannot set Exif data using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif data using Exiv2 ", e);
     }    
 
     return false;    
@@ -335,7 +335,7 @@ bool KExiv2::setIptc(Exiv2::DataBuf const data)
         if (!d->filePath.isEmpty())
             qDebug ("From file %s", d->filePath.ascii());
 
-        qDebug("Cannot set Iptc data using Exiv2 (%s)",e.what().c_str());
+        printExiv2ExceptionError("Cannot set Iptc data using Exiv2 ", e);
     }        
 
     return false;
@@ -370,9 +370,10 @@ bool KExiv2::load(const QString& filePath)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot load metadata using Exiv2 (%s)", e.what().c_str());
-        return false;
+        printExiv2ExceptionError("Cannot load metadata using Exiv2 ", e);
     }
+    
+    return false;
 }
 
 bool KExiv2::save(const QString& filePath)
@@ -426,9 +427,10 @@ bool KExiv2::save(const QString& filePath)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot save metadata using Exiv2 (%s)", e.what().c_str());
-        return false;
+        printExiv2ExceptionError("Cannot save metadata using Exiv2 ", e);
     }
+
+    return false;
 }
 
 bool KExiv2::applyChanges()
@@ -451,10 +453,36 @@ bool KExiv2::setImageProgramId(const QString& program, const QString& version)
 {
     try
     {
-        QString software(program);
-        software.append("-");
-        software.append(version);
-        d->exifMetadata["Exif.Image.Software"]              = software.ascii();
+	// Record program info in Exif.Image.ProcessingSoftware tag (only available with Exiv2 >= 0.14.0).
+    
+#ifdef EXIV2_CHECK_VERSION 
+        if (EXIV2_CHECK_VERSION(0,14,0))
+        {
+            QString software(program);
+            software.append("-");
+            software.append(version);
+            d->exifMetadata["Exif.Image.ProcessingSoftware"] = software.ascii();
+        }
+#endif
+
+        // See B.K.O #142564: Check if Exif.Image.Software already exist. If yes, do not touch this tag.
+            
+        if (!d->exifMetadata.empty())
+	{
+            Exiv2::ExifData exifData(d->exifMetadata);
+            Exiv2::ExifKey key("Exif.Image.Software");
+            Exiv2::ExifData::iterator it = exifData.findKey(key);
+       
+            if (it == exifData.end())
+	    {
+                QString software(program);
+                software.append("-");
+                software.append(version);
+                d->exifMetadata["Exif.Image.Software"]      = software.ascii();
+	    }
+	}
+
+	// Record program info in IPTC tags.
 
         d->iptcMetadata["Iptc.Application2.Program"]        = program.ascii();
         d->iptcMetadata["Iptc.Application2.ProgramVersion"] = version.ascii();
@@ -462,13 +490,13 @@ bool KExiv2::setImageProgramId(const QString& program, const QString& version)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Program identity into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Program identity into image using Exiv2 ", e);
     }
 
     return false;
 }
 
-QSize KExiv2::getImageDimensions()
+QSize KExiv2::getImageDimensions() const
 {
     if (d->exifMetadata.empty())
         return QSize();
@@ -517,7 +545,7 @@ QSize KExiv2::getImageDimensions()
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot parse image dimensions tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot parse image dimensions tag using Exiv2 ", e);
     }        
     
     return QSize();
@@ -538,7 +566,7 @@ bool KExiv2::setImageDimensions(const QSize& size, bool setProgramName)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set image dimensions using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set image dimensions using Exiv2 ", e);
     }        
     
     return false;
@@ -615,7 +643,7 @@ QImage KExiv2::getExifThumbnail(bool fixOrientation) const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot get Exif Thumbnail using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot get Exif Thumbnail using Exiv2 ", e);
     }        
     
     return thumbnail;
@@ -638,13 +666,13 @@ bool KExiv2::setExifThumbnail(const QImage& thumb, bool setProgramName)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif Thumbnail using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif Thumbnail using Exiv2 ", e);
     }        
     
     return false;
 }
 
-KExiv2::ImageOrientation KExiv2::getImageOrientation()
+KExiv2::ImageOrientation KExiv2::getImageOrientation() const
 {
     if (d->exifMetadata.empty())
        return ORIENTATION_UNSPECIFIED;
@@ -729,7 +757,7 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation()
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot parse Exif Orientation tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot parse Exif Orientation tag using Exiv2 ", e);
     }
 
     return ORIENTATION_UNSPECIFIED;
@@ -797,13 +825,13 @@ bool KExiv2::setImageOrientation(ImageOrientation orientation, bool setProgramNa
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif Orientation tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif Orientation tag using Exiv2 ", e);
     }        
     
     return false;
 }
 
-KExiv2::ImageColorWorkSpace KExiv2::getImageColorWorkSpace()
+KExiv2::ImageColorWorkSpace KExiv2::getImageColorWorkSpace() const
 {
     if (d->exifMetadata.empty())
         return WORKSPACE_UNSPECIFIED;
@@ -838,7 +866,7 @@ KExiv2::ImageColorWorkSpace KExiv2::getImageColorWorkSpace()
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot parse image color workspace tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot parse image color workspace tag using Exiv2 ", e);
     }        
     
     return WORKSPACE_UNSPECIFIED;    
@@ -860,7 +888,7 @@ bool KExiv2::setImageColorWorkSpace(ImageColorWorkSpace workspace, bool setProgr
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif color workspace tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif color workspace tag using Exiv2 ", e);
     }        
     
     return false;
@@ -989,7 +1017,7 @@ QDateTime KExiv2::getImageDateTime() const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot parse Exif date & time tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot parse Exif date & time tag using Exiv2 ", e);
     }        
     
     return QDateTime();
@@ -1034,13 +1062,13 @@ bool KExiv2::setImageDateTime(const QDateTime& dateTime, bool setDateTimeDigitiz
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Date & Time into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Date & Time into image using Exiv2 ", e);
     }        
     
     return false;
 }
 
-bool KExiv2::getImagePreview(QImage& preview)
+bool KExiv2::getImagePreview(QImage& preview) const
 {
     try
     {
@@ -1052,7 +1080,7 @@ bool KExiv2::getImagePreview(QImage& preview)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot get image preview using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot get image preview using Exiv2 ", e);
     }
 
     return false;
@@ -1094,7 +1122,7 @@ bool KExiv2::setImagePreview(const QImage& preview, bool setProgramName)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot get image preview using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot get image preview using Exiv2 ", e);
     }
 
     return false;
@@ -1121,8 +1149,8 @@ QString KExiv2::getExifTagString(const char* exifTagName, bool escapeCR) const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot find Exif key '%s' into image using Exiv2 (%s)",
-               exifTagName, e.what().c_str());
+        printExiv2ExceptionError(QString("Cannot find Exif key '%1' into image using Exiv2 ")
+                                 .arg(exifTagName), e);
     }
 
     return QString();
@@ -1140,7 +1168,7 @@ bool KExiv2::setExifTagString(const char *exifTagName, const QString& value, boo
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif tag string into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif tag string into image using Exiv2 ", e);
     }
 
     return false;
@@ -1167,8 +1195,8 @@ QString KExiv2::getIptcTagString(const char* iptcTagName, bool escapeCR) const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot find Iptc key '%s' into image using Exiv2 (%s)",
-               iptcTagName, e.what().c_str());
+        printExiv2ExceptionError(QString("Cannot find Iptc key '%1' into image using Exiv2 ")
+                                 .arg(iptcTagName), e);
     }
 
     return QString();
@@ -1186,13 +1214,13 @@ bool KExiv2::setIptcTagString(const char *iptcTagName, const QString& value, boo
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Iptc tag string into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Iptc tag string into image using Exiv2 ", e);
     }
 
     return false;
 }
 
-bool KExiv2::getExifTagLong(const char* exifTagName, long &val)
+bool KExiv2::getExifTagLong(const char* exifTagName, long &val) const
 {
     try
     {    
@@ -1207,8 +1235,8 @@ bool KExiv2::getExifTagLong(const char* exifTagName, long &val)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot find Exif key '%s' into image using Exiv2 (%s)", 
-               exifTagName, e.what().c_str());
+        printExiv2ExceptionError(QString("Cannot find Exif key '%1' into image using Exiv2 ")
+                                 .arg(exifTagName), e);
     }        
     
     return false;    
@@ -1231,8 +1259,8 @@ QByteArray KExiv2::getExifTagData(const char* exifTagName) const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot find Exif key '%s' into image using Exiv2 (%s)",
-               exifTagName, e.what().c_str());
+        printExiv2ExceptionError(QString("Cannot find Exif key '%1' into image using Exiv2 ")
+                                 .arg(exifTagName), e);
     }
 
     return QByteArray();
@@ -1255,14 +1283,14 @@ QByteArray KExiv2::getIptcTagData(const char *iptcTagName) const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot find Iptc key '%s' into image using Exiv2 (%s)", 
-                iptcTagName, e.what().c_str());
+        printExiv2ExceptionError(QString("Cannot find Iptc key '%1' into image using Exiv2 ")
+                                 .arg(iptcTagName), e);
     }
 
     return QByteArray();
 }
 
-bool KExiv2::getExifTagRational(const char *exifTagName, long int &num, long int &den, int component)
+bool KExiv2::getExifTagRational(const char *exifTagName, long int &num, long int &den, int component) const
 {
     try
     {
@@ -1278,8 +1306,8 @@ bool KExiv2::getExifTagRational(const char *exifTagName, long int &num, long int
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot find Exif Rational value from key '%s' into image using Exiv2 (%s)",
-               exifTagName, e.what().c_str());
+        printExiv2ExceptionError(QString("Cannot find Exif Rational value from key '%1' " 
+                                         "into image using Exiv2 ").arg(exifTagName), e);
     }
 
     return false;
@@ -1297,7 +1325,7 @@ bool KExiv2::setExifTagLong(const char *exifTagName, long val, bool setProgramNa
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif tag long value into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif tag long value into image using Exiv2 ", e);
     }
 
     return false;
@@ -1315,7 +1343,7 @@ bool KExiv2::setExifTagRational(const char *exifTagName, long int num, long int
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif tag rational value into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif tag rational value into image using Exiv2 ", e);
     }
 
     return false;
@@ -1323,19 +1351,21 @@ bool KExiv2::setExifTagRational(const char *exifTagName, long int num, long int
 
 bool KExiv2::setExifTagData(const char *exifTagName, const QByteArray& data, bool setProgramName)
 {
+    if (data.isEmpty())
+	return false;
+
     if (!setProgramId(setProgramName))
         return false;
 
     try
     {
-        Exiv2::DataValue val;
-        val.read((Exiv2::byte *)data.data(), data.size());
+        Exiv2::DataValue val((Exiv2::byte *)data.data(), data.size());
         d->exifMetadata[exifTagName] = val;
         return true;
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif tag data into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif tag data into image using Exiv2 ", e);
     }
 
     return false;
@@ -1343,19 +1373,21 @@ bool KExiv2::setExifTagData(const char *exifTagName, const QByteArray& data, boo
 
 bool KExiv2::setIptcTagData(const char *iptcTagName, const QByteArray& data, bool setProgramName)
 {
+    if (data.isEmpty())
+	return false;
+	
     if (!setProgramId(setProgramName))
         return false;
 
     try
-    {
-        Exiv2::DataValue val;
-        val.read((Exiv2::byte *)data.data(), data.size());
+    {	
+        Exiv2::DataValue val((Exiv2::byte *)data.data(), data.size());
         d->iptcMetadata[iptcTagName] = val;
         return true;
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Iptc tag data into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Iptc tag data into image using Exiv2 ", e);
     }
 
     return false;
@@ -1378,7 +1410,7 @@ bool KExiv2::removeExifTag(const char *exifTagName, bool setProgramName)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot remove Exif tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot remove Exif tag using Exiv2 ", e);
     }        
     
     return false;
@@ -1401,13 +1433,13 @@ bool KExiv2::removeIptcTag(const char *iptcTagName, bool setProgramName)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot remove Iptc tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot remove Iptc tag using Exiv2 ", e);
     }        
     
     return false;
 }
 
-bool KExiv2::getGPSInfo(double& altitude, double& latitude, double& longitude)
+bool KExiv2::getGPSInfo(double& altitude, double& latitude, double& longitude) const
 {
     try
     {    
@@ -1499,7 +1531,7 @@ bool KExiv2::getGPSInfo(double& altitude, double& latitude, double& longitude)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot get Exif GPS tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot get Exif GPS tag using Exiv2 ", e);
     }        
     
     return false;
@@ -1573,11 +1605,11 @@ bool KExiv2::setGPSInfo(double altitude, double latitude, double longitude, bool
         // as the sign is encoded in LatRef.
         // Further note: original code did not translate between
         //   dd.dddddd to dd mm.mm - that's why we now multiply
-        //   by 6000 - x60 to get minutes, x100 to get to mmmm/100.
+        //   by 6000 - x60 to get minutes, x1000000 to get to mmmm/1000000.
         value = Exiv2::Value::create(Exiv2::signedRational);
         deg   = (int)floor(fabs(latitude)); // Slice off after decimal.
-        min   = (int)floor((fabs(latitude) - floor(fabs(latitude))) * 6000);
-        snprintf(scratchBuf, 100, "%ld/1 %ld/100 0/1", deg, min);
+        min   = (int)floor((fabs(latitude) - floor(fabs(latitude))) * 60000000);
+        snprintf(scratchBuf, 100, "%ld/1 %ld/1000000 0/1", deg, min);
         value->read(scratchBuf);
         d->exifMetadata.add(Exiv2::ExifKey("Exif.GPSInfo.GPSLatitude"), value.get());
         
@@ -1610,11 +1642,11 @@ bool KExiv2::setGPSInfo(double altitude, double latitude, double longitude, bool
         // as the sign is encoded in LongRef.
         // Further note: original code did not translate between
         //   dd.dddddd to dd mm.mm - that's why we now multiply
-        //   by 6000 - x60 to get minutes, x100 to get to mmmm/100.
+        //   by 6000 - x60 to get minutes, x1000000 to get to mmmm/1000000.
         value = Exiv2::Value::create(Exiv2::signedRational);
         deg   = (int)floor(fabs(longitude)); // Slice off after decimal.
-        min   = (int)floor((fabs(longitude) - floor(fabs(longitude))) * 6000);
-        snprintf(scratchBuf, 100, "%ld/1 %ld/100 0/1", deg, min);
+        min   = (int)floor((fabs(longitude) - floor(fabs(longitude))) * 60000000);
+        snprintf(scratchBuf, 100, "%ld/1 %ld/1000000 0/1", deg, min);
         value->read(scratchBuf);
         d->exifMetadata.add(Exiv2::ExifKey("Exif.GPSInfo.GPSLongitude"), value.get());
     
@@ -1622,7 +1654,7 @@ bool KExiv2::setGPSInfo(double altitude, double latitude, double longitude, bool
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif GPS tag using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif GPS tag using Exiv2 ", e);
     }        
     
     return false;
@@ -1658,7 +1690,7 @@ bool KExiv2::removeGPSInfo(bool setProgramName)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot remove Exif GPS tag using Exiv2 (%s)",e.what().c_str());
+        printExiv2ExceptionError("Cannot remove Exif GPS tag using Exiv2 ", e);
     }        
     
     return false;
@@ -1749,7 +1781,7 @@ QStringList KExiv2::getImageKeywords() const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot get IPTC Keywords from image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot get IPTC Keywords from image using Exiv2 ", e);
     }        
     
     return QStringList();
@@ -1806,7 +1838,7 @@ bool KExiv2::setImageKeywords(const QStringList& oldKeywords, const QStringList&
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set IPTC Keywords into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set IPTC Keywords into image using Exiv2 ", e);
     }        
     
     return false;
@@ -1837,7 +1869,7 @@ QStringList KExiv2::getImageSubjects() const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot get IPTC Subjects from image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot get IPTC Subjects from image using Exiv2 ", e);
     }        
     
     return QStringList();
@@ -1889,7 +1921,7 @@ bool KExiv2::setImageSubjects(const QStringList& oldSubjects, const QStringList&
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set IPTC Subjects into image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set IPTC Subjects into image using Exiv2 ", e);
     }        
     
     return false;
@@ -1920,7 +1952,7 @@ QStringList KExiv2::getImageSubCategories() const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot get IPTC Sub Categories from image using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot get IPTC Sub Categories from image using Exiv2 ", e);
     }        
     
     return QStringList();
@@ -1952,7 +1984,8 @@ bool KExiv2::setImageSubCategories(const QStringList& oldSubCategories, const QS
                 ++it;
         };
 
-        // Add new Sub Categories. Note that SubCategories IPTC tag is limited to 32 char but can be redondant.
+        // Add new Sub Categories. Note that SubCategories IPTC tag is limited to 32 
+        // characters but can be redondant.
 
         Exiv2::IptcKey iptcTag("Iptc.Application2.SuppCategory");
 
@@ -1972,7 +2005,7 @@ bool KExiv2::setImageSubCategories(const QStringList& oldSubCategories, const QS
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set IPTC Sub Categories into image using Exiv2 (%s)",e.what().c_str());
+        printExiv2ExceptionError("Cannot set IPTC Sub Categories into image using Exiv2 ", e);
     }        
     
     return false;
@@ -2000,7 +2033,7 @@ QString KExiv2::getExifComment() const
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot find Exif User Comment using Exiv2 (%s)",e.what().c_str());
+        printExiv2ExceptionError("Cannot find Exif User Comment using Exiv2 ", e);
     }
 
     return QString();
@@ -2043,7 +2076,7 @@ bool KExiv2::setExifComment(const QString& comment, bool setProgramName)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot set Exif Comment using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot set Exif Comment using Exiv2 ", e);
     }
 
     return false;
@@ -2114,7 +2147,7 @@ QString KExiv2::convertCommentValue(const Exiv2::Exifdatum &exifDatum)
     }
     catch( Exiv2::Error &e )
     {
-        qDebug("Cannot convert Comment using Exiv2 (%s)", e.what().c_str());
+        printExiv2ExceptionError("Cannot convert Comment using Exiv2 ", e);
     }
 
     return QString();
